USCA5 Opinions

http://www.ca5.uscourts.gov/Rss.aspx?Feed=Opinions&amp;Which=All&amp;Style=Detail USCA5 Opinions released between 10/31/2014 - 11/7/2014 Fri, 07 Nov 2014 19:43:49 GMT 11-50792 Jesus Hernandez, et al v. USA, et al http://www.ca5.uscourts.gov/opinions/pub/11/11-50792.eborder.pdf 11-50792
Jesus Hernandez, et al v. USA, et al
pub
Civil Rights
11/7/2014
Fri, 07 Nov 2014 12:05:01 GMT 425925 13-10264 USA v. Jose Hernandez http://www.ca5.uscourts.gov/opinions/unpub/13/13-10264.0.pdf 13-10264
USA v. Jose Hernandez
unpub
Prisoner w/ out Counsel
11/7/2014
Fri, 07 Nov 2014 18:05:02 GMT 425929 13-10984 USA v. Jay Oswalt http://www.ca5.uscourts.gov/opinions/pub/13/13-10984-CR0.pdf 13-10984
USA v. Jay Oswalt
pub
Direct Criminal
11/7/2014
Fri, 07 Nov 2014 18:05:02 GMT 425932 13-11283 Robert Jehling v. Belo Corporation, et al http://www.ca5.uscourts.gov/opinions/unpub/13/13-11283.0.pdf 13-11283
Robert Jehling v. Belo Corporation, et al
unpub
Civil Rights
11/7/2014
Fri, 07 Nov 2014 18:05:02 GMT 425933 13-11339 USA v. Sol Peoples http://www.ca5.uscourts.gov/opinions/unpub/13/13-11339.0.pdf 13-11339
USA v. Sol Peoples
unpub
Direct Criminal
11/7/2014
Fri, 07 Nov 2014 18:05:02 GMT 425931 13-31074 USA v. Chavo Thomas, et al http://www.ca5.uscourts.gov/opinions/unpub/13/13-31074.0.pdf 13-31074
USA v. Chavo Thomas, et al
unpub
Direct Criminal
11/7/2014
Fri, 07 Nov 2014 12:05:01 GMT 425926 13-50075 Barron & Newburger, P.C. v. Texas Skyline, Limited http://www.ca5.uscourts.gov/opinions/pub/13/13-50075.ebord.pdf 13-50075
Barron & Newburger, P.C. v. Texas Skyline, Limited
pub
Bankruptcy
11/7/2014
Fri, 07 Nov 2014 12:05:01 GMT 425924 13-51190 USA v. Rogelio Macedo http://www.ca5.uscourts.gov/opinions/unpub/13/13-51190.0.pdf 13-51190
USA v. Rogelio Macedo
unpub
Direct Criminal
11/7/2014
Fri, 07 Nov 2014 18:05:02 GMT 425849 14-10191 Ronald Parham v. Ryder System, Incorporated http://www.ca5.uscourts.gov/opinions/unpub/14/14-10191.0.pdf 14-10191
Ronald Parham v. Ryder System, Incorporated
unpub
Private Civil Diversity
11/7/2014
Fri, 07 Nov 2014 18:05:01 GMT 425756 14-10494 Juanin Suarez-O'Neil v. Sims http://www.ca5.uscourts.gov/opinions/unpub/14/14-10494.0.pdf 14-10494
Juanin Suarez-O'Neil v. Sims
unpub
Prisoner w/ out Counsel
11/7/2014
Fri, 07 Nov 2014 12:05:01 GMT 425927 14-10671 Sharleen Jeanbaptiste v. Wells Fargo Bank, N.A. http://www.ca5.uscourts.gov/opinions/unpub/14/14-10671.0.pdf 14-10671
Sharleen Jeanbaptiste v. Wells Fargo Bank, N.A.
unpub
Private Civil Diversity
11/7/2014
Fri, 07 Nov 2014 12:05:01 GMT 425928 14-40178 USA v. Diego Castellanos-Cruz http://www.ca5.uscourts.gov/opinions/unpub/14/14-40178.0.pdf 14-40178
USA v. Diego Castellanos-Cruz
unpub
Direct Criminal
11/7/2014
Fri, 07 Nov 2014 18:05:02 GMT 425930 14-50148 George Matassarin v. Denis Grosvenor, et al http://www.ca5.uscourts.gov/opinions/unpub/14/14-50148.0.pdf 14-50148
George Matassarin v. Denis Grosvenor, et al
unpub
Private Civil Diversity
11/7/2014
Fri, 07 Nov 2014 18:05:02 GMT 425934 12-30883 In Re: Deepwater Horizon http://www.ca5.uscourts.gov/opinions/pub/12/12-30883-CV0.pdf 12-30883
In Re: Deepwater Horizon
pub
Private Civil Federal
11/5/2014
Wed, 05 Nov 2014 18:05:02 GMT 424525 13-10829 Software Development Technol v. Trizetto Corporati http://www.ca5.uscourts.gov/opinions/unpub/13/13-10829.0.pdf 13-10829
Software Development Technol v. Trizetto Corporati
unpub
Private Civil Diversity
11/5/2014
Wed, 05 Nov 2014 18:05:02 GMT 425910 13-11388 USA v. David Felts http://www.ca5.uscourts.gov/opinions/unpub/13/13-11388.0.pdf 13-11388
USA v. David Felts
unpub
Direct Criminal
11/5/2014
Wed, 05 Nov 2014 18:05:03 GMT 425911 13-20211 Lisa Mabary v. Home Town Bank, N.A. http://www.ca5.uscourts.gov/opinions/pub/13/13-20211-CV0.pdf 13-20211
Lisa Mabary v. Home Town Bank, N.A.
pub
Private Civil Federal
11/5/2014
Wed, 05 Nov 2014 18:05:03 GMT 425913 13-20699 USA v. Alonzo Harris http://www.ca5.uscourts.gov/opinions/unpub/13/13-20699.0.pdf 13-20699
USA v. Alonzo Harris
unpub
Direct Criminal
11/5/2014
Wed, 05 Nov 2014 18:05:02 GMT 425906 13-30185 Luther Scott, Jr., et al v. Tom Schedler http://www.ca5.uscourts.gov/opinions/pub/13/13-30185-CV0.pdf 13-30185
Luther Scott, Jr., et al v. Tom Schedler
pub
Civil Rights
11/5/2014
Wed, 05 Nov 2014 18:05:02 GMT 425909 13-41330 USA v. Luis Mazarego-Salazar http://www.ca5.uscourts.gov/opinions/unpub/13/13-41330.0.pdf 13-41330
USA v. Luis Mazarego-Salazar
unpub
Direct Criminal
11/5/2014
Wed, 05 Nov 2014 18:05:02 GMT 425908 14-10555 Janet Smith v. JP Morgan Chase Bank, N.A. http://www.ca5.uscourts.gov/opinions/unpub/14/14-10555.0.pdf 14-10555
Janet Smith v. JP Morgan Chase Bank, N.A.
unpub
Private Civil Diversity
11/5/2014
Wed, 05 Nov 2014 18:05:02 GMT 425907 14-20107 Dennis Shaver, et al v. National City Mortgage, et http://www.ca5.uscourts.gov/opinions/unpub/14/14-20107.0.pdf 14-20107
Dennis Shaver, et al v. National City Mortgage, et
unpub
Private Civil Diversity
11/5/2014
Wed, 05 Nov 2014 12:05:03 GMT 425903 14-30053 Thomas Roque v. Natchitoches Parish School Bd http://www.ca5.uscourts.gov/opinions/unpub/14/14-30053.0.pdf 14-30053
Thomas Roque v. Natchitoches Parish School Bd
unpub
Civil Rights
11/5/2014
Wed, 05 Nov 2014 18:05:02 GMT 425905 14-30204 Joanne Stone v. Louisiana Dept of Revenue http://www.ca5.uscourts.gov/opinions/unpub/14/14-30204.0.pdf 14-30204
Joanne Stone v. Louisiana Dept of Revenue
unpub
Civil Rights
11/5/2014
Wed, 05 Nov 2014 12:05:04 GMT 425904 14-30274 Marcus Preston v. K. Ask-Carlson http://www.ca5.uscourts.gov/opinions/unpub/14/14-30274.0.pdf 14-30274
Marcus Preston v. K. Ask-Carlson
unpub
Prisoner w/ out Counsel
11/5/2014
Wed, 05 Nov 2014 12:05:03 GMT 425902 14-40303 Maria Vaillancourt v. PNC Bank, N.A. http://www.ca5.uscourts.gov/opinions/pub/14/14-40303-CV0.pdf 14-40303
Maria Vaillancourt v. PNC Bank, N.A.
pub
Private Civil Diversity
11/5/2014
Wed, 05 Nov 2014 18:05:03 GMT 425912 13-10344 Anthony Walker v. William Stephens, Director http://www.ca5.uscourts.gov/opinions/unpub/13/13-10344.0.pdf 13-10344
Anthony Walker v. William Stephens, Director
unpub
Prisoner w/ out Counsel
10/31/2014
Fri, 31 Oct 2014 12:05:04 GMT 425827 13-20506 USA v. Ryan Solis http://www.ca5.uscourts.gov/opinions/unpub/13/13-20506.0.pdf 13-20506
USA v. Ryan Solis
unpub
Direct Criminal
10/31/2014
Fri, 31 Oct 2014 12:05:04 GMT 425828 14-40542 Richard Cavada, Sr. v. John McHugh http://www.ca5.uscourts.gov/opinions/unpub/14/14-40542.0.pdf 14-40542
Richard Cavada, Sr. v. John McHugh
unpub
Civil Rights
10/31/2014
Fri, 31 Oct 2014 18:05:01 GMT 425829 13-10839 USA v. Anthony Rodden http://www.ca5.uscourts.gov/opinions/unpub/13/13-10839.0.pdf 13-10839
USA v. Anthony Rodden
unpub
Prisoner w/ out Counsel
11/6/2014
Thu, 06 Nov 2014 12:05:01 GMT 425915 13-50954 USA v. Juan Lomas-Rodriguez http://www.ca5.uscourts.gov/opinions/unpub/13/13-50954.0.pdf 13-50954
USA v. Juan Lomas-Rodriguez
unpub
Direct Criminal
11/6/2014
Thu, 06 Nov 2014 18:05:01 GMT 425923 13-51181 USA v. Steven Donoso http://www.ca5.uscourts.gov/opinions/unpub/13/13-51181.0.pdf 13-51181
USA v. Steven Donoso
unpub
Direct Criminal
11/6/2014
Thu, 06 Nov 2014 18:05:01 GMT 425920 13-60496 Martha Gomez-Montes v. Eric Holder, Jr. http://www.ca5.uscourts.gov/opinions/unpub/13/13-60496.0.pdf 13-60496
Martha Gomez-Montes v. Eric Holder, Jr.
unpub
Immigration
11/6/2014
Thu, 06 Nov 2014 18:05:01 GMT 425919 14-10589 USA v. Archie Goodman http://www.ca5.uscourts.gov/opinions/unpub/14/14-10589.0.pdf 14-10589
USA v. Archie Goodman
unpub
Direct Criminal
11/6/2014
Thu, 06 Nov 2014 18:05:01 GMT 425918 14-30090 James Koon v. Burl Cain, Warden http://www.ca5.uscourts.gov/opinions/unpub/14/14-30090.0.pdf 14-30090
James Koon v. Burl Cain, Warden
unpub
Prisoner w/ out Counsel
11/6/2014
Thu, 06 Nov 2014 18:05:01 GMT 425916 14-30130 USA v. Michael Davis, Jr. http://www.ca5.uscourts.gov/opinions/unpub/14/14-30130.0.pdf 14-30130
USA v. Michael Davis, Jr.
unpub
Direct Criminal
11/6/2014
Thu, 06 Nov 2014 12:05:01 GMT 425914 14-40223 Marcus Grant v. Annie Anthony, et al http://www.ca5.uscourts.gov/opinions/unpub/14/14-40223.0.pdf 14-40223
Marcus Grant v. Annie Anthony, et al
unpub
Prisoner w/ out Counsel
11/6/2014
Thu, 06 Nov 2014 18:05:01 GMT 425922 14-50125 USA v. Mateo Mendez http://www.ca5.uscourts.gov/opinions/unpub/14/14-50125.0.pdf 14-50125
USA v. Mateo Mendez
unpub
Direct Criminal
11/6/2014
Thu, 06 Nov 2014 18:05:01 GMT 425917 14-50205 Cecilia Aranda v. Dal-Tile Corporation http://www.ca5.uscourts.gov/opinions/unpub/14/14-50205.0.pdf 14-50205
Cecilia Aranda v. Dal-Tile Corporation
unpub
Civil Rights
11/6/2014
Thu, 06 Nov 2014 18:05:01 GMT 425921 13-11100 USA v. Herbert Jena http://www.ca5.uscourts.gov/opinions/unpub/13/13-11100.0.pdf 13-11100
USA v. Herbert Jena
unpub
Non Direct Criminal
11/3/2014
Mon, 03 Nov 2014 12:05:01 GMT 425832 13-20274 USA v. Thuong Vo, et al http://www.ca5.uscourts.gov/opinions/unpub/13/13-20274.0.pdf 13-20274
USA v. Thuong Vo, et al
unpub
Direct Criminal
11/3/2014
Mon, 03 Nov 2014 12:05:01 GMT 425831 13-20764 BAC Home Loans Servicing, L.P. v. TX Realty Holdin http://www.ca5.uscourts.gov/opinions/unpub/13/13-20764.0.pdf 13-20764
BAC Home Loans Servicing, L.P. v. TX Realty Holdin
unpub
Private Civil Federal
11/3/2014
Mon, 03 Nov 2014 18:05:02 GMT 425848 13-40922 USA v. Jose Perfecto-Mendoza http://www.ca5.uscourts.gov/opinions/unpub/13/13-40922.0.pdf 13-40922
USA v. Jose Perfecto-Mendoza
unpub
Direct Criminal
11/3/2014
Mon, 03 Nov 2014 18:05:02 GMT 425839 13-41153 Holt Texas, Limited, et al v. T.S.C. Seiber Servic http://www.ca5.uscourts.gov/opinions/pub/13/13-41153-CV0.pdf 13-41153
Holt Texas, Limited, et al v. T.S.C. Seiber Servic
pub
Bankruptcy
11/3/2014
Mon, 03 Nov 2014 12:05:01 GMT 425833 13-41349 USA v. Rafael Albornoz-Albornoz http://www.ca5.uscourts.gov/opinions/pub/13/13-41349-CR0.pdf 13-41349
USA v. Rafael Albornoz-Albornoz
pub
Direct Criminal
11/3/2014
Mon, 03 Nov 2014 18:05:02 GMT 425836 13-50747 Hunt Building Company, Limited, et al v. John Hanc http://www.ca5.uscourts.gov/opinions/unpub/13/13-50747.0.pdf 13-50747
Hunt Building Company, Limited, et al v. John Hanc
unpub
Private Civil Diversity
11/3/2014
Mon, 03 Nov 2014 18:05:02 GMT 425853 13-50912 James Negley v. FBI http://www.ca5.uscourts.gov/opinions/unpub/13/13-50912.0.pdf 13-50912
James Negley v. FBI
unpub
United States Civil
11/3/2014
Mon, 03 Nov 2014 12:05:01 GMT 425830 13-51117 USA v. Rodrigo Rodriguez-Negrete http://www.ca5.uscourts.gov/opinions/pub/13/13-51117-CR0.pdf 13-51117
USA v. Rodrigo Rodriguez-Negrete
pub
Direct Criminal
11/3/2014
Mon, 03 Nov 2014 18:05:02 GMT 425841 13-60064 USA v. Lonzo Griffin http://www.ca5.uscourts.gov/opinions/unpub/13/13-60064.0.pdf 13-60064
USA v. Lonzo Griffin
unpub
Direct Criminal
11/3/2014
Mon, 03 Nov 2014 18:05:02 GMT 425840 13-60698 USA v. Bobbie Sandford http://www.ca5.uscourts.gov/opinions/unpub/13/13-60698.0.pdf 13-60698
USA v. Bobbie Sandford
unpub
Direct Criminal
11/3/2014
Mon, 03 Nov 2014 18:05:02 GMT 425846 14-20159 Quasi Jackson v. Deutsche Bank Trust Company, et a http://www.ca5.uscourts.gov/opinions/unpub/14/14-20159.0.pdf 14-20159
Quasi Jackson v. Deutsche Bank Trust Company, et a
unpub
Private Civil Diversity
11/3/2014
Mon, 03 Nov 2014 18:05:02 GMT 425842 14-20314 Tony Cheng v. Schlumberger http://www.ca5.uscourts.gov/opinions/unpub/14/14-20314.0.pdf 14-20314
Tony Cheng v. Schlumberger
unpub
Civil Rights
11/3/2014
Mon, 03 Nov 2014 18:05:02 GMT 425852 14-30009 USA v. Randy Wilson http://www.ca5.uscourts.gov/opinions/unpub/14/14-30009.0.pdf 14-30009
USA v. Randy Wilson
unpub
Direct Criminal
11/3/2014
Mon, 03 Nov 2014 18:05:02 GMT 425835 14-30247 Brandon Lavergne v. Tiffany Lejuene http://www.ca5.uscourts.gov/opinions/unpub/14/14-30247.0.pdf 14-30247
Brandon Lavergne v. Tiffany Lejuene
unpub
Prisoner w/ out Counsel
11/3/2014
Mon, 03 Nov 2014 18:05:02 GMT 425845 14-30250 Brandon Lavergne v. Holly Bergeran http://www.ca5.uscourts.gov/opinions/unpub/14/14-30250.0.pdf 14-30250
Brandon Lavergne v. Holly Bergeran
unpub
Prisoner w/ out Counsel
11/3/2014
Mon, 03 Nov 2014 18:05:02 GMT 425837 14-30281 Brandon Lavergne v. Claire Taylor, et al http://www.ca5.uscourts.gov/opinions/unpub/14/14-30281 0.pdf 14-30281
Brandon Lavergne v. Claire Taylor, et al
unpub
Prisoner w/ out Counsel
11/3/2014
Mon, 03 Nov 2014 18:05:02 GMT 425847 14-30304 Brandon Lavergne v. John Faulk http://www.ca5.uscourts.gov/opinions/unpub/14/14-30304.0.pdf 14-30304
Brandon Lavergne v. John Faulk
unpub
Prisoner w/ out Counsel
11/3/2014
Mon, 03 Nov 2014 18:05:02 GMT 425843 14-30307 Brandon Lavergne v. Kent Kloster http://www.ca5.uscourts.gov/opinions/unpub/14/14-30307.0.pdf 14-30307
Brandon Lavergne v. Kent Kloster
unpub
Prisoner w/ out Counsel
11/3/2014
Mon, 03 Nov 2014 18:05:02 GMT 425844 14-40081 Maria Perez v. Texas A & M University, et al http://www.ca5.uscourts.gov/opinions/unpub/14/14-40081.0.pdf 14-40081
Maria Perez v. Texas A & M University, et al
unpub
Civil Rights
11/3/2014
Mon, 03 Nov 2014 18:05:02 GMT 425834 14-40142 USA v. Ronald Guevara http://www.ca5.uscourts.gov/opinions/unpub/14/14-40142.0.pdf 14-40142
USA v. Ronald Guevara
unpub
Direct Criminal
11/3/2014
Mon, 03 Nov 2014 18:05:02 GMT 425838 14-40366 Dwight Harrison v. Bert Bell/Pete Rozelle NFL http://www.ca5.uscourts.gov/opinions/unpub/14/14-40366.0.pdf 14-40366
Dwight Harrison v. Bert Bell/Pete Rozelle NFL
unpub
Private Civil Federal
11/3/2014
Mon, 03 Nov 2014 18:05:02 GMT 425851 14-98001 In Re: Donna Grodner http://www.ca5.uscourts.gov/opinions/unpub/14/14-98001.0.pdf 14-98001
In Re: Donna Grodner
unpub
Miscellaneous
11/3/2014
Mon, 03 Nov 2014 18:05:02 GMT 425850 13-11418 USA v. Crystal Compton http://www.ca5.uscourts.gov/opinions/unpub/13/13-11418.0.pdf 13-11418
USA v. Crystal Compton
unpub
Direct Criminal
11/4/2014
Tue, 04 Nov 2014 18:05:03 GMT 425890 13-20656 USA v. Domingo Espinoza http://www.ca5.uscourts.gov/opinions/unpub/13/13-20656.0.pdf 13-20656
USA v. Domingo Espinoza
unpub
Direct Criminal
11/4/2014
Tue, 04 Nov 2014 18:05:02 GMT 425863 13-20706 USA v. Jose Mazariegos-Campos http://www.ca5.uscourts.gov/opinions/unpub/13/13-20706.0.pdf 13-20706
USA v. Jose Mazariegos-Campos
unpub
Direct Criminal
11/4/2014
Tue, 04 Nov 2014 18:05:02 GMT 425871 13-31264 USA v. Christopher Willis http://www.ca5.uscourts.gov/opinions/unpub/13/13-31264.0.pdf 13-31264
USA v. Christopher Willis
unpub
Direct Criminal
11/4/2014
Tue, 04 Nov 2014 18:05:03 GMT 425893 13-40970 USA v. Donald Barnes http://www.ca5.uscourts.gov/opinions/unpub/13/13-40970.0.pdf 13-40970
USA v. Donald Barnes
unpub
Direct Criminal
11/4/2014
Tue, 04 Nov 2014 18:05:03 GMT 425899 13-40984 USA v. Pedro Navarro, Jr. http://www.ca5.uscourts.gov/opinions/unpub/13/13-40984.0.pdf 13-40984
USA v. Pedro Navarro, Jr.
unpub
Direct Criminal
11/4/2014
Tue, 04 Nov 2014 18:05:03 GMT 425894 13-41051 USA v. Leon Wilson http://www.ca5.uscourts.gov/opinions/unpub/13/13-41051.0.pdf 13-41051
USA v. Leon Wilson
unpub
Direct Criminal
11/4/2014
Tue, 04 Nov 2014 18:05:03 GMT 425896 13-41075 USA v. Yered Morales-Alvarez http://www.ca5.uscourts.gov/opinions/unpub/13/13-41075.0.pdf 13-41075
USA v. Yered Morales-Alvarez
unpub
Direct Criminal
11/4/2014
Tue, 04 Nov 2014 18:05:02 GMT 425875 13-41246 USA v. Kevin Ortega http://www.ca5.uscourts.gov/opinions/unpub/13/13-41246.0.pdf 13-41246
USA v. Kevin Ortega
unpub
Direct Criminal
11/4/2014
Tue, 04 Nov 2014 18:05:03 GMT 425898 13-41249 USA v. Julio Escobar-Alvarado http://www.ca5.uscourts.gov/opinions/unpub/13/13-41249.0.pdf 13-41249
USA v. Julio Escobar-Alvarado
unpub
Direct Criminal
11/4/2014
Tue, 04 Nov 2014 18:05:02 GMT 425878 13-41280 USA v. Salvador Barrera http://www.ca5.uscourts.gov/opinions/unpub/13/13-41280.0.pdf 13-41280
USA v. Salvador Barrera
unpub
Direct Criminal
11/4/2014
Tue, 04 Nov 2014 18:05:03 GMT 425900 13-41324 USA v. Jesus Islas-Saucedo http://www.ca5.uscourts.gov/opinions/unpub/13/13-41324.0.pdf 13-41324
USA v. Jesus Islas-Saucedo
unpub
Direct Criminal
11/4/2014
Tue, 04 Nov 2014 18:05:02 GMT 425862 13-41339 USA v. Rodrio Pedomo http://www.ca5.uscourts.gov/opinions/unpub/13/13-41339.0.pdf 13-41339
USA v. Rodrio Pedomo
unpub
Direct Criminal
11/4/2014
Tue, 04 Nov 2014 18:05:02 GMT 425879 13-50262 USA v. Carlos Guerrero http://www.ca5.uscourts.gov/opinions/unpub/13/13-50262.0.pdf 13-50262
USA v. Carlos Guerrero
unpub
Direct Criminal
11/4/2014
Tue, 04 Nov 2014 18:05:03 GMT 425901 13-50677 USA v. Raymundo Rodriguez http://www.ca5.uscourts.gov/opinions/unpub/13/13-50677.0.pdf 13-50677
USA v. Raymundo Rodriguez
unpub
Direct Criminal
11/4/2014
Tue, 04 Nov 2014 18:05:02 GMT 425866 13-51152 USA v. Keith Judd http://www.ca5.uscourts.gov/opinions/unpub/13/13-51152.0.pdf 13-51152
USA v. Keith Judd
unpub
Direct Criminal
11/4/2014
Tue, 04 Nov 2014 12:05:01 GMT 425858 13-60680 Ghanshyambbhai Patel v. Eric Holder, Jr. http://www.ca5.uscourts.gov/opinions/unpub/13/13-60680.0.pdf 13-60680
Ghanshyambbhai Patel v. Eric Holder, Jr.
unpub
Immigration
11/4/2014
Tue, 04 Nov 2014 12:05:01 GMT 425856 13-60898 Victor De Leon-Saj v. Eric Holder, Jr. http://www.ca5.uscourts.gov/opinions/unpub/13/13-60898.0.pdf 13-60898
Victor De Leon-Saj v. Eric Holder, Jr.
unpub
Immigration
11/4/2014
Tue, 04 Nov 2014 12:05:01 GMT 425857 14-10076 USA v. Dustin Pulido http://www.ca5.uscourts.gov/opinions/unpub/14/14-10076.0.pdf 14-10076
USA v. Dustin Pulido
unpub
Direct Criminal
11/4/2014
Tue, 04 Nov 2014 18:05:02 GMT 425869 14-10082 USA v. Traci Ramos http://www.ca5.uscourts.gov/opinions/unpub/14/14-10082.0.pdf 14-10082
USA v. Traci Ramos
unpub
Direct Criminal
11/4/2014
Tue, 04 Nov 2014 18:05:03 GMT 425883 14-10209 USA v. Larry Boykin, Jr. http://www.ca5.uscourts.gov/opinions/unpub/14/14-10209.0.pdf 14-10209
USA v. Larry Boykin, Jr.
unpub
Direct Criminal
11/4/2014
Tue, 04 Nov 2014 18:05:03 GMT 425887 14-10339 USA v. David Gonzalez, Jr. http://www.ca5.uscourts.gov/opinions/unpub/14/14-10339.0.pdf 14-10339
USA v. David Gonzalez, Jr.
unpub
Direct Criminal
11/4/2014
Tue, 04 Nov 2014 18:05:03 GMT 425892 14-10420 USA v. Jessica Smith http://www.ca5.uscourts.gov/opinions/unpub/14/14-10420.0.pdf 14-10420
USA v. Jessica Smith
unpub
Direct Criminal
11/4/2014
Tue, 04 Nov 2014 18:05:03 GMT 425895 14-10477 USA v. Ronald Riva, III http://www.ca5.uscourts.gov/opinions/unpub/14/14-10477.0.pdf 14-10477
USA v. Ronald Riva, III
unpub
Direct Criminal
11/4/2014
Tue, 04 Nov 2014 18:05:03 GMT 425897 14-20158 Joe Hollingshead v. Aetna Health, Incorporated http://www.ca5.uscourts.gov/opinions/unpub/14/14-20158.0.pdf 14-20158
Joe Hollingshead v. Aetna Health, Incorporated
unpub
Private Civil Federal
11/4/2014
Tue, 04 Nov 2014 12:05:01 GMT 425854 14-20160 USA v. Salvador Juarez-Uribe http://www.ca5.uscourts.gov/opinions/unpub/14/14-20160.0.pdf 14-20160
USA v. Salvador Juarez-Uribe
unpub
Direct Criminal
11/4/2014
Tue, 04 Nov 2014 18:05:02 GMT 425877 14-20179 USA v. Cristian Perez http://www.ca5.uscourts.gov/opinions/unpub/14/14-20179.0.pdf 14-20179
USA v. Cristian Perez
unpub
Direct Criminal
11/4/2014
Tue, 04 Nov 2014 18:05:02 GMT 425881 14-30045 USA v. Clifton Earl http://www.ca5.uscourts.gov/opinions/unpub/14/14-30045.0.pdf 14-30045
USA v. Clifton Earl
unpub
Direct Criminal
11/4/2014
Tue, 04 Nov 2014 18:05:02 GMT 425882 14-30076 USA v. Vincent Thomas http://www.ca5.uscourts.gov/opinions/unpub/14/14-30076.0.pdf 14-30076
USA v. Vincent Thomas
unpub
Direct Criminal
11/4/2014
Tue, 04 Nov 2014 18:05:03 GMT 425884 14-30221 USA v. Elvin Pigott http://www.ca5.uscourts.gov/opinions/unpub/14/14-30221.0.pdf 14-30221
USA v. Elvin Pigott
unpub
Direct Criminal
11/4/2014
Tue, 04 Nov 2014 18:05:02 GMT 425874 14-30233 USA v. Eric Witherwax http://www.ca5.uscourts.gov/opinions/unpub/14/14-30233.0.pdf 14-30233
USA v. Eric Witherwax
unpub
Direct Criminal
11/4/2014
Tue, 04 Nov 2014 18:05:02 GMT 425876 14-30299 Tony Chaney v. Races and Aces, et al http://www.ca5.uscourts.gov/opinions/unpub/14/14-30299.0.pdf 14-30299
Tony Chaney v. Races and Aces, et al
unpub
Civil Rights
11/4/2014
Tue, 04 Nov 2014 18:05:02 GMT 425860 14-30329 Christopher White v. Howard Brown, et al http://www.ca5.uscourts.gov/opinions/unpub/14/14-30329.0.pdf 14-30329
Christopher White v. Howard Brown, et al
unpub
Prisoner w/ out Counsel
11/4/2014
Tue, 04 Nov 2014 18:05:02 GMT 425865 14-30489 World Wrestling Entertainment v. Unidentified Part http://www.ca5.uscourts.gov/opinions/pub/14/14-30489-CV0.pdf 14-30489
World Wrestling Entertainment v. Unidentified Part
pub
Private Civil Federal
11/4/2014
Tue, 04 Nov 2014 12:05:01 GMT 425859 14-40070 USA v. Cory Randall http://www.ca5.uscourts.gov/opinions/unpub/14/14-40070.0.pdf 14-40070
USA v. Cory Randall
unpub
Direct Criminal
11/4/2014
Tue, 04 Nov 2014 18:05:03 GMT 425885 14-40077 USA v. Manuel Perez-Alvarez http://www.ca5.uscourts.gov/opinions/unpub/14/14-40077.0.pdf 14-40077
USA v. Manuel Perez-Alvarez
unpub
Direct Criminal
11/4/2014
Tue, 04 Nov 2014 18:05:03 GMT 425889 14-40110 USA v. Misael Bustos-Gutierrez http://www.ca5.uscourts.gov/opinions/unpub/14/14-40110.0.pdf 14-40110
USA v. Misael Bustos-Gutierrez
unpub
Direct Criminal
11/4/2014
Tue, 04 Nov 2014 18:05:02 GMT 425861 14-40167 USA v. Manuel Mosqueda-Jaramillo http://www.ca5.uscourts.gov/opinions/unpub/14/14-40167.0.pdf 14-40167
USA v. Manuel Mosqueda-Jaramillo
unpub
Direct Criminal
11/4/2014
Tue, 04 Nov 2014 18:05:02 GMT 425864 14-40199 USA v. Harley Peterson http://www.ca5.uscourts.gov/opinions/unpub/14/14-40199.0.pdf 14-40199
USA v. Harley Peterson
unpub
Direct Criminal
11/4/2014
Tue, 04 Nov 2014 18:05:02 GMT 425867 14-40210 USA v. Jorge Knight-Castillo http://www.ca5.uscourts.gov/opinions/unpub/14/14-40210.0.pdf 14-40210
USA v. Jorge Knight-Castillo
unpub
Direct Criminal
11/4/2014
Tue, 04 Nov 2014 18:05:02 GMT 425873 14-40215 USA v. Rolando Mendez-Robledo http://www.ca5.uscourts.gov/opinions/unpub/14/14-40215.0.pdf 14-40215
USA v. Rolando Mendez-Robledo
unpub
Direct Criminal
11/4/2014
Tue, 04 Nov 2014 18:05:02 GMT 425868 14-40238 USA v. Alejandro Cruz-Marquez http://www.ca5.uscourts.gov/opinions/unpub/14/14-40238.0.pdf 14-40238
USA v. Alejandro Cruz-Marquez
unpub
Direct Criminal
11/4/2014
Tue, 04 Nov 2014 18:05:02 GMT 425870 14-40305 USA v. Salvador Juarez-Uribe http://www.ca5.uscourts.gov/opinions/unpub/14/14-40305.0.pdf 14-40305
USA v. Salvador Juarez-Uribe
unpub
Direct Criminal
11/4/2014
Tue, 04 Nov 2014 18:05:02 GMT 425880 14-50010 USA v. Jose Hernandez http://www.ca5.uscourts.gov/opinions/unpub/14/14-50010.0.pdf 14-50010
USA v. Jose Hernandez
unpub
Direct Criminal
11/4/2014
Tue, 04 Nov 2014 18:05:03 GMT 425886 14-50031 USA v. Jose Munoz http://www.ca5.uscourts.gov/opinions/unpub/14/14-50031.0.pdf 14-50031
USA v. Jose Munoz
unpub
Direct Criminal
11/4/2014
Tue, 04 Nov 2014 18:05:03 GMT 425888 14-50059 USA v. Acxel Ambrocio-Castaneda http://www.ca5.uscourts.gov/opinions/unpub/14/14-50059.0.pdf 14-50059
USA v. Acxel Ambrocio-Castaneda
unpub
Direct Criminal
11/4/2014
Tue, 04 Nov 2014 12:05:01 GMT 425855 14-50156 USA v. Mario Tolayo-Ordunio http://www.ca5.uscourts.gov/opinions/unpub/14/14-50156.0.pdf 14-50156
USA v. Mario Tolayo-Ordunio
unpub
Direct Criminal
11/4/2014
Tue, 04 Nov 2014 18:05:02 GMT 425872 14-50172 USA v. Melissa Paxton http://www.ca5.uscourts.gov/opinions/unpub/14/14-50172.0.pdf 14-50172
USA v. Melissa Paxton
unpub
Direct Criminal
11/4/2014
Tue, 04 Nov 2014 18:05:03 GMT 425891